@@ -1,4 +1,4 @@
-test_that("simulation runs with simInit and spades with set.seed", {
+test_that("simulation runs with simInit and spades with set.seed; events arg", {
   skip_if_not_installed("RandomFields")
 
   testInitOut <- testInit()
@@ -11,7 +11,7 @@ test_that("simulation runs with simInit and spades with set.seed", {
   times <- list(start = 0.0, end = 1, timeunit = "year")
   params <- list(
     .globals = list(burnStats = "npixelsburned", stackName = "landscape"),
-    randomLandscapes = list(.plotInitialTime = NA, .plotInterval = NA),
+    randomLandscapes = list(.plotInitialTime = NA, .plotInterval = NA, .seed = list("init" = 321)),
     caribouMovement = list(.plotInitialTime = NA, .plotInterval = NA, torus = TRUE),
     fireSpread = list(.plotInitialTime = NA, .plotInterval = NA)
   )
@@ -31,6 +31,95 @@ test_that("simulation runs with simInit and spades with set.seed", {
   expect_equivalent(start(mySim), 0.0)
   expect_equivalent(end(mySim), 1.0)
   expect_true(all.equal(mySim2, mySim))
+
+
+  # Test events argument in spades call
+  expect_true(!all("init" == completed(mySim)$eventType))
+  expect_true(max(events(mySim)$eventTime) > end(mySim)) # didn't schedule next event
+  expect_true(all("stats" %in% completed(mySim)$eventType))
+
+  set.seed(123)
+  mySimEvent <- simInit(times, params, modules, objects = list(), paths) %>%
+    spades(debug = FALSE, .plotInitialTime = NA, events = "init")
+  expect_true(all("init" == completed(mySimEvent)$eventType))
+  expect_true(max(events(mySimEvent)$eventTime) <= end(mySimEvent)) # didn't schedule next event
+
+
+  eventTypes <- c("init", "burn")
+  mySimEvent2 <- simInit(times, params, modules, objects = list(), paths) %>%
+    spades(debug = FALSE, .plotInitialTime = NA, events = eventTypes)
+  expect_true(all(eventTypes %in% completed(mySimEvent2)$eventType))
+
+  eventTypes <- c()
+  mySimEvent3 <- simInit(times, params, modules, objects = list(), paths) %>%
+    spades(debug = FALSE, .plotInitialTime = NA, events = eventTypes)
+  expect_true(all(eventTypes %in% completed(mySimEvent3)$eventType))
+  expect_true(identical(completed(mySimEvent3)[,1:4], completed(mySim)[,1:4]))
+
+  eventTypes <- c("nothing")
+  mySimEvent4 <- simInit(times, params, modules, objects = list(), paths) %>%
+    spades(debug = FALSE, .plotInitialTime = NA, events = eventTypes)
+  expect_true(NROW(completed(mySimEvent4)) == 0) # nothing completed
+  expect_true(all("init" == events(mySimEvent4)$eventType)) # nothing happened; only inits in queue
+
+  eventTypes <- list(randomLandscapes = c("init"),
+                     fireSpread = c("init", "burn")
+  )
+  mySimEvent5 <- simInit(times, params, modules, objects = list(), paths) %>%
+    spades(debug = FALSE, .plotInitialTime = NA, events = eventTypes)
+  expect_true(all(unique(unlist(eventTypes)) %in% completed(mySimEvent5)$eventType))
+  expect_true(!all("stats" %in% completed(mySimEvent5)$eventType))
+
+  # Typo or "run events that aren't there"
+  eventTypes <- list(randomLandscapes = c("init"),
+                     fireSpread = c("initial", "burn")
+  )
+  mySimEvent6 <- simInit(times, params, modules, objects = list(), paths) %>%
+    spades(debug = FALSE, .plotInitialTime = NA, events = eventTypes)
+  expect_true(all("randomLandscapes" %in% completed(mySimEvent6)$moduleName))
+  expect_true(!all("fireSpread" %in% completed(mySimEvent6)$moduleName)) # didn't run any fireSpread events b/c misspelled
+  expect_true(all("fireSpread" %in% events(mySimEvent6)$moduleName)) # didn't run any fireSpread events b/c misspelled
+
+  mySimEvent7 <- simInit(times, params, modules, objects = list(), paths) %>%
+    spades(debug = FALSE, .plotInitialTime = NA, events = eventTypes, cache = TRUE)
+  expect_true(all("randomLandscapes" %in% completed(mySimEvent7)$moduleName))
+  expect_true(!all("fireSpread" %in% completed(mySimEvent7)$moduleName)) # didn't run any fireSpread events b/c misspelled
+  expect_true(all("fireSpread" %in% events(mySimEvent7)$moduleName)) # didn't run any fireSpread events b/c misspelled
+
+  mySimEvent8 <- simInit(times, params, modules, objects = list(), paths) %>%
+    spades(debug = FALSE, .plotInitialTime = NA, events = eventTypes, cache = TRUE)
+  expect_true(all("randomLandscapes" %in% completed(mySimEvent8)$moduleName))
+  expect_true(!all("fireSpread" %in% completed(mySimEvent8)$moduleName)) # didn't run any fireSpread events b/c misspelled
+  expect_true(all("fireSpread" %in% events(mySimEvent8)$moduleName)) # didn't run any fireSpread events b/c misspelled
+
+
+  mySimEvent9 <- simInitAndSpades(times, params, modules, objects = list(), paths,
+                        debug = FALSE, .plotInitialTime = NA, events = "init")
+  expect_true(all("init" == completed(mySimEvent9)$eventType))
+  expect_true(max(events(mySimEvent9)$eventTime) <= end(mySimEvent9)) # didn't schedule next event
+
+  # Test times
+  #  Set end time to WAY after the init events
+  mySimEvent10 <- simInitAndSpades(times = list(start = 0, end = 10), params, modules, objects = list(), paths,
+                                  debug = FALSE, .plotInitialTime = NA, events = "init")
+  expect_true(time(mySimEvent10) == end(mySimEvent10)) # it is at 10, the end
+  expect_true(all("init" == completed(mySimEvent10)$eventType))
+  expect_true(max(completed(mySimEvent10)$eventTime) == start(mySimEvent10)) # didn't go past start time because init are all at start
+  simOut <- spades(mySimEvent10)
+  expect_true(time(simOut) == end(simOut)) # it is at 10, the end
+  expect_true(!all("init" == completed(simOut)$eventType))
+  expect_true(max(completed(simOut)$eventTime) == end(simOut)) # got to end time
+
+
+  mySimEvent11 <- simInit(times = list(start = 2000, end = 2010), params, modules,
+                          objects = list(), paths,
+                          # events = "init",
+                          outputs = data.frame(objectName = "landscape", saveTime = 2000:2010,
+                                               eventPriority = 1))
+  mess <- capture_messages(mySimEvent11Out <- spades(Copy(mySimEvent11),
+                                                     event = list(randomLandscapes = "init")))
+  expect_true(any(grepl("not specified", mess)))
+
 })
 
 test_that("spades calls - diff't signatures", {
@@ -56,8 +145,12 @@ test_that("spades calls - diff't signatures", {
   expect_equivalent(capture_output(spades(a, debug = "current", .plotInitialTime = NA)),
                     capture_output(spades(a, debug = TRUE, .plotInitialTime = NA)))
 
-  expect_message(spades(Copy(a), debug = list(debug = list("current", "events")), .plotInitialTime = NA),
+  if (requireNamespace("logging", quietly = TRUE))
+    expect_message(spades(Copy(a), debug = list(debug = list("current", "events")), .plotInitialTime = NA),
         "eventTime *moduleName *eventType *eventPriority")
+  else
+    expect_warning(expect_message(spades(Copy(a), debug = list(debug = list("current", "events")), .plotInitialTime = NA),
+                   "eventTime *moduleName *eventType *eventPriority"))
   expect_message(spades(a, debug = c("current", "events"), .plotInitialTime = NA),
                 "moduleName")
   expect_message(spades(a, debug = "simList", .plotInitialTime = NA),
@@ -332,8 +425,7 @@ test_that("conflicting function types", {
 
   xxx1 <- gsub(xxx, pattern = 'plotFun', replacement = 'Plot') # nolint
   cat(xxx1, file = fileName, sep = "\n")
-  expect_message(simInit(paths = list(modulePath = tmpdir), modules = m),
-                 "Plot is defined")
+  expect_message(simInit(paths = list(modulePath = tmpdir), modules = m), "Plot is defined")
 
   # do functions like raster::levels
   cat(xxx[1:lineWithInit], "
@@ -350,8 +442,7 @@ test_that("conflicting function types", {
 
   mm <- capture_messages(simInit(paths = list(modulePath = tmpdir), modules = m))
 
-  fullMessage <- c("the following function\\(s\\) is used that",
-                   "raster::scale", "scale")
+  fullMessage <- c("the following function\\(s\\) is used that", "raster::scale", "scale")
   expect_true(all(unlist(lapply(fullMessage, function(x) any(grepl(mm, pattern = x))))))
   nonMessage <- c("raster::levels", "levels")
   expect_false(all(unlist(lapply(nonMessage, function(x) any(grepl(mm, pattern = x))))))
@@ -363,10 +454,8 @@ test_that("conflicting function types", {
       ",
       xxx[(lineWithInit + 1):length(xxx)], sep = "\n", fill = FALSE, file = fileName)
 
-  expect_message(simInit(paths = list(modulePath = tmpdir), modules = m),
-                 "raster::scale")
+  expect_message(simInit(paths = list(modulePath = tmpdir), modules = m), "raster::scale")
 
-  ###
   cat(xxx[1:lineWithInit], "
       library(raster)
       poiuoiu <- raster(extent(0,10,0,10), vals = rep(1:2, length.out = 100))
@@ -375,8 +464,7 @@ test_that("conflicting function types", {
       ",
       xxx[(lineWithInit + 1):length(xxx)], sep = "\n", fill = FALSE, file = fileName)
 
-  expect_message(simInit(paths = list(modulePath = tmpdir), modules = m),
-                 "poiuoiu is assigned")
+  expect_message(simInit(paths = list(modulePath = tmpdir), modules = m), "poiuoiu is assigned")
 
   cat(xxx[1:(lineWithInit - 1)], "
       a <- function(x) {
@@ -385,8 +473,7 @@ test_that("conflicting function types", {
       ",
       xxx[(lineWithInit):length(xxx)], sep = "\n", fill = FALSE, file = fileName)
 
-  expect_message(simInit(paths = list(modulePath = tmpdir), modules = m),
-                 "a: parameter")
+  expect_message(simInit(paths = list(modulePath = tmpdir), modules = m), "a: parameter")
 
   xxx1 <- gsub(xxx, pattern = "\\.plotInitialTime", replacement = "value")
   xxx1 <- gsub(xxx1, pattern = "NA, NA, NA", replacement = "'hi', NA, NA")
@@ -406,14 +493,15 @@ test_that("conflicting function types", {
 
   mm <- capture_messages(simInit(paths = list(modulePath = tmpdir), modules = m))
 
-  fullMessage <- c("defineParameter: 'value' is not of specified type 'numeric'",
+  fullMessage <- c(# "defineParameter: 'value' is not of specified type 'numeric'",
                    "defineParameter: 'plotInterval' is not of specified type 'numeric'",
                    "defineParameter: 'saveInitialTime' is not of specified type 'numeric'",
                    "defineParameter: 'saveInterval' is not of specified type 'numeric'",
                    "child4: module code: Init: local variable.*qwerqwer.*assigned but may not be used",
-                   "Running .inputObjects for child4", "child4: module code: Init: local variable.*poiuoiu.*assigned but may not be used",
+                   "Running .inputObjects for child4",
+                   "child4: module code: Init: local variable.*poiuoiu.*assigned but may not be used",
                    "child4: outputObjects: g, g1 are assigned to sim inside Init, but are not declared in metadata outputObjects",
-                   "child4: inputObjects: b, d, f, hi, d1, test are used from sim inside Init, but are not declared in metadata inputObjects"
+                   "child4: inputObjects: b, d, f, d1, test are used from sim inside Init, but are not declared in metadata inputObjects"
   )
 
   mm <- cleanMessage(mm)
@@ -442,7 +530,7 @@ test_that("conflicting function types", {
   cat(xxx[1:(lineWithInputObjects - 1)], "
       expectsInput('a', 'numeric', '', '')
       ",
-      xxx[(lineWithInputObjects+1):length(xxx)], sep = "\n", fill = FALSE, file = fileName)
+      xxx[(lineWithInputObjects + 1):length(xxx)], sep = "\n", fill = FALSE, file = fileName)
 
   expect_message(simInit(paths = list(modulePath = tmpdir), modules = m),
                  c(paste0(m, ": module code: a is declared in metadata inputObjects")))
@@ -494,7 +582,6 @@ test_that("conflicting function types", {
   expect_message(simInit(paths = list(modulePath = tmpdir), modules = m),
                  c(paste0(m, ": module code: doEvent.",m," must return")))
 
-
   lineWithInputObjects <- grep(xxx, pattern = " expectsInput")
   lineWithOutputObjects <- grep(xxx, pattern = " createsOutput")
   lineWithDotInputObjects <- grep(xxx, pattern = "\\.inputObjects")[1]
@@ -579,24 +666,16 @@ paste0("      url1 <- extractURL('ei4', sim = sim, module = \"",m,"\")"),"
   x2 <- lapply(sns, function(sn) {
     slot(mySim@depends@dependencies[[m]], sn)
   })
-  expect_true(any(unlist(lapply(x2, function(v)
-    grepl("  |\n", v)))))
+  expect_true(any(unlist(lapply(x2, function(v) grepl("  |\n", v)))))
   x2 <- rmExtraSpacesEOLList(x2)
-  expect_false(any(unlist(lapply(x1, function(v)
-    grepl("  |\n", v)))))
-  expect_false(any(unlist(lapply(x2, function(v)
-    grepl("  |\n", v)))))
+  expect_false(any(unlist(lapply(x1, function(v) grepl("  |\n", v)))))
+  expect_false(any(unlist(lapply(x2, function(v) grepl("  |\n", v)))))
   x1 <- moduleParams(m, dirname(dirname(fileName)))
-  expect_false(any(unlist(lapply(x1, function(v)
-    grepl("  |\n", v)))))
+  expect_false(any(unlist(lapply(x1, function(v) grepl("  |\n", v)))))
   x1 <- moduleInputs(m, dirname(dirname(fileName)))
-  expect_false(any(unlist(lapply(x1, function(v)
-    grepl("  |\n", v)))))
+  expect_false(any(unlist(lapply(x1, function(v) grepl("  |\n", v)))))
   x1 <- moduleOutputs(m, dirname(dirname(fileName)))
-  expect_false(any(unlist(lapply(x1, function(v)
-    grepl("  |\n", v)))))
-
-
+  expect_false(any(unlist(lapply(x1, function(v) grepl("  |\n", v)))))
 })
 
 test_that("scheduleEvent with NA logical in a non-standard parameter", {
@@ -616,7 +695,8 @@ test_that("scheduleEvent with NA logical in a non-standard parameter", {
   xxx2b <- gsub(",$", grep("time interval between plot", xxx1, value = TRUE), replacement = "")
   xxx3 <- parse(text = paste(xxx2a, xxx2b))
   # show that it is logical
-  expect_true(is.logical(eval(xxx3)$default[[1]]))
+  sim <- simInit(times = list(start = 0, end = 2))
+  expect_true(is.numeric(eval(xxx3)$default[[1]]))
 
   mm <- capture_messages(simInit(paths = list(modulePath = tmpdir), modules = m))
   expect_true(all(unlist(lapply(c("Running .inputObjects", "module code appears clean"),
@@ -728,7 +808,7 @@ test_that("messaging with multiple modules", {
       sep = "\n", fill = FALSE, file = fileNames[2])
 
   fullMessage <- c(
-    "defineParameter: 'plotInitialTime' is not of specified type 'character'",
+    # "defineParameter: 'plotInitialTime' is not of specified type 'character'",
     "defineParameter: 'saveInitialTime' is not of specified type 'character'",
     "Running .inputObjects for test",
     "test: module code: co2, co3 are declared in metadata outputObjects, but are not assigned in the module",
@@ -742,7 +822,7 @@ test_that("messaging with multiple modules", {
     "test: inputObjects: g, co1 are assigned to sim inside .inputObjects, but are not declared in metadata inputObjects",
     "test: inputObjects: b, aaa are used from sim inside Init, but are not declared in metadata inputObjects",
     "test: inputObjects: b, co3 are used from sim inside .inputObjects, but are not declared in metadata inputObjects",
-    "defineParameter: 'plotInitialTime' is not of specified type 'character'",
+    # "defineParameter: 'plotInitialTime' is not of specified type 'character'",
     "Running .inputObjects for test2",
     "test2: module code: co1, co4 are declared in metadata outputObjects, but are not assigned in the module",
     "test2: module code: ei1, ei4 are declared in metadata inputObjects, but no default\\(s\\) are provided in .inputObjects",
@@ -752,7 +832,7 @@ test_that("messaging with multiple modules", {
     "test2: inputObjects: co1 is assigned to sim inside .inputObjects, but is not declared in metadata inputObjects",
     "test2: inputObjects: b is used from sim inside Init, but is not declared in metadata inputObjects",
     "test2: inputObjects: b is used from sim inside .inputObjects, but is not declared in metadata inputObjects",
-    "defineParameter: 'plotInitialTime' is not of specified type 'character'",
+    # "defineParameter: 'plotInitialTime' is not of specified type 'character'",
     "defineParameter: 'hello' is not of specified type 'character'",
     "Running .inputObjects for test3",
     "test3: module code appears clean",
@@ -903,7 +983,7 @@ test_that("debug using logging", {
   skip_if_not_installed("RandomFields")
 
   testInitOut <- testInit(tmpFileExt = "log")
-  if (requireNamespace("logging")) {
+  if (requireNamespace("logging", quietly = TRUE)) {
     on.exit({
       testOnExit(testInitOut)
     }, add = TRUE)
@@ -964,7 +1044,7 @@ test_that("debug using logging", {
     expect_false(file.exists(tmpfile))
     expect_true(length(mess2) == 0)
     expect_true(any(grepl("total elpsd", mess1)))
-    expect_true(any(grepl(Sys.Date(), mess1))) # the straight messages don't have date
+    expect_true(any(grepl(format(Sys.Date(), "%h%d"), mess1))) # the straight messages don't have date
 
     # Test whether suppressMessages works
     mess1 <- capture_messages({
@@ -989,3 +1069,202 @@ test_that("debug using logging", {
     expect_true(length(mess1) == 0)
   }
 })
+
+test_that("Plots function", {
+  if (require("ggplot2")) {
+    testInitOut <- testInit()
+    on.exit({
+      testOnExit(testInitOut)
+    }, add = TRUE)
+
+    newModule("test", tmpdir, open = FALSE)
+
+    # Sept 18 2018 -- Changed to use "seconds" -- better comparison with simple loop
+    outs <- list(c("png", "object", "raw"),
+                 c("png", "object"),
+                 c("png", "raw"),
+                 c("raw"),
+                 NULL)
+    .plotInitialTimes <- c(NA_integer_, NA_integer_, 1L, 1L, NA_integer_)
+    iii <- 0
+    for (out in outs) {
+      iii <- iii + 1
+      .plotInitialTime <- .plotInitialTimes[iii]
+
+      lll <- capture.output(dput(out))
+      fn <- "testing"
+      wdth <- 4.77
+      fnForCat <- capture.output(dput(fn))
+      cat(file = file.path(tmpdir, "test", "test.R"),'
+      defineModule(sim, list(
+      name = "test",
+      description = "insert module description here",
+      keywords = c("insert key words here"),
+      authors = person(c("Eliot", "J", "B"), "McIntire", email = "eliot.mcintire@canada.ca", role = c("aut", "cre")),
+      childModules = character(0),
+      version = list(SpaDES.core = "0.1.0", test = "0.0.1"),
+      spatialExtent = raster::extent(rep(NA_real_, 4)),
+      timeframe = as.POSIXlt(c(NA, NA)),
+      timeunit = "year",
+      citation = list("citation.bib"),
+      documentation = list("README.txt", "test.Rmd"),
+      reqdPkgs = list("ggplot2"),
+      parameters = rbind(
+        defineParameter(".plotsToDisk", "character", ',lll,', NA, NA, "lala"),
+        defineParameter(".plotInitialTime", "numeric", ',.plotInitialTime,', NA, NA, "lala")
+      ),
+      inputObjects = bindrows(
+      ),
+      outputObjects = bindrows(
+      )
+      ))
+
+      doEvent.test = function(sim, eventTime, eventType, debug = FALSE) {
+      switch(
+      eventType,
+      init = {
+        sim <- scheduleEvent(sim, time(sim) + 1, "test", "event1", .skipChecks = TRUE)
+        sim$something <- data.frame(a = sample(1:10, replace = TRUE))
+        Plots(data = sim$something, fn = fn1, filename = ',fnForCat,', bins = 10, fill = "red",
+              ggsaveArgs = list(width = ',wdth,'))
+      },
+      event1 = {
+      sim <- scheduleEvent(sim, time(sim) + 1, "test", "event1", .skipChecks = TRUE)
+      })
+      return(invisible(sim))
+      }
+      fn1 <- function(d, bins, ...) {
+          ggplot(d, aes(a)) +
+          geom_histogram(bins = bins, ...) +
+          labs(title = "hello")
+        }
+
+
+
+      ', fill = TRUE)
+      sim <- simInit(modules = "test", paths = list(modulePath = tmpdir),
+                     times = list(start = 0, end = 10, timeunit = "year"))
+      mess <- capture_messages(simOut <- spades(sim, debug = TRUE))
+      files <- dir(file.path(outputPath(sim), "figures"), full.names = TRUE)
+      expect_true(all(grepl(fn, files)))
+      if (iii == 5) {
+        expect_true(length(files) == 0L)
+      }
+      if (any(grepl("object", out)))
+        expect_true(any(grepl("gg", files)))
+      if (any(grepl("raw", out)))
+        expect_true(any(grepl("qs", files) & !grepl("gg", files)))
+      if (any(grepl("png", out))) {
+        expect_true(any(grepl("png", files)))
+        expect_true(sum(grepl(wdth, mess)) == 1)
+      }
+      if (any(grepl("pdf", out)))
+        expect_true(any(grepl("pdf", files)))
+
+      unlink(files)
+    }
+  }
+
+  if (interactive()) {
+    something <- data.frame(a = sample(1:10, replace = TRUE))
+    fn1 <- function(d, bins, title = "hello", ...) {
+      ggplot(d, aes(a)) +
+        geom_histogram(bins = bins, ...) +
+        labs(title = title)
+    }
+    # Should add next 2 plots to same windows
+    Plots(data = something, fn = fn1, bins = 10, fill = "red", types = "screen", title = "run1")
+    Plots(data = something, fn = fn1, bins = 10, fill = "red", types = "screen", title = "run2")
+    # Should clear plot windows and each of following will be a new plot on its own
+    Plots(data = something, fn = fn1, bins = 10, fill = "red", types = "screen", title = "run3", usePlot = FALSE)
+    Plots(data = something, fn = fn1, bins = 10, fill = "red", types = "screen", title = "run4", usePlot = FALSE)
+  }
+
+})
+
+test_that("testing .plotInitialTime & .plots", {
+  if (interactive()) {
+    skip_if_not_installed("RandomFields")
+
+    testInitOut <- testInit()
+    on.exit({
+      testOnExit(testInitOut)
+    }, add = TRUE)
+
+    times <- list(start = 0.0, end = 1, timeunit = "year")
+    params <- list(
+      .globals = list(burnStats = "npixelsburned", stackName = "landscape"),
+      randomLandscapes = list(.plotInitialTime = NA, .plotInterval = NA),
+      caribouMovement = list(.plotInitialTime = NA, .plotInterval = NA, torus = TRUE),
+      fireSpread = list(.plotInitialTime = NA, .plotInterval = NA)
+    )
+    modules <- list("randomLandscapes", #"caribouMovement",
+                    "fireSpread")
+    paths <- list(modulePath = system.file("sampleModules", package = "SpaDES.core"))
+
+    mySim <- simInit(times, params, modules, objects = list(), paths)
+
+    mySim@params$randomLandscapes$.plotInitialTime <- 0
+    mySim@params$fireSpread$.plotInitialTime <- 0
+    mySim@params$caribouMovement$.plotInitialTime <- 0
+
+    # Makes plots
+    spades(mySim)
+    # Makes no plots
+    spades(mySim, .plots = NA)
+    spades(mySim, .plotInitialTime = NA)
+
+  }
+})
+
+test_that("Plots function", {
+  if (require("ggplot2")) {
+    testInitOut <- testInit()
+    on.exit({
+      testOnExit(testInitOut)
+    }, add = TRUE)
+
+    newModule("test", tmpdir, open = FALSE)
+
+    # Sept 18 2018 -- Changed to use "seconds" -- better comparison with simple loop
+    cat(file = file.path(tmpdir, "test", "test.R"),'
+      defineModule(sim, list(
+      name = "test",
+      description = "insert module description here",
+      keywords = c("insert key words here"),
+      authors = person(c("Eliot", "J", "B"), "McIntire", email = "eliot.mcintire@canada.ca", role = c("aut", "cre")),
+      childModules = character(0),
+      version = list(SpaDES.core = "0.1.0", test = "0.0.1"),
+      spatialExtent = raster::extent(rep(NA_real_, 4)),
+      timeframe = as.POSIXlt(c(NA, NA)),
+      timeunit = "year",
+      citation = list("citation.bib"),
+      documentation = list("README.txt", "test.Rmd"),
+      reqdPkgs = list("SpaDES.core (>= 3.0)", "SpaDES.core (>= 3.3)", "SpaDES.core (>= 1.0)"),
+      parameters = rbind(
+      ),
+      inputObjects = bindrows(
+      ),
+      outputObjects = bindrows(
+      )
+      ))
+
+      doEvent.test = function(sim, eventTime, eventType, debug = FALSE) {
+      switch(
+      eventType,
+      init = {
+      },
+      event1 = {
+      })
+      return(invisible(sim))
+      }
+      fn1 <- function(d, bins, ...) {
+          ggplot(d, aes(a)) +
+          geom_histogram(bins = bins, ...)
+        }
+  ', fill = TRUE)
+      expect_error(sim <- simInit(modules = "test", paths = list(modulePath = tmpdir),
+                     times = list(start = 0, end = 10, timeunit = "year")),
+                   "needs a newer version of SpaDES.core")
+  }
+})
